<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Instellingen van uitvoerder</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Vormgeving</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Plaatsing:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Marge aan bovenkant</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Width:</source>
        <translation>Breedte:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="57"/>
        <source>With multiple screens, if the window is shown on the focused screen,
this value is only for the smallest screen. The minimum width is 400 px.</source>
        <translation>Met meerdere beeldschermen is er altijd één scherm dat gefocust is. Als het venster
daarop staat, dan is deze waarde voor het kleinste scherm. Minimale breedte: 400 px.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="61"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="71"/>
        <source>Show on:</source>
        <translation>Tonen op:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="108"/>
        <source>Show history first</source>
        <translation>Geschiedenis bovenaan tonen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="101"/>
        <source>Store/show history</source>
        <translation>Geschiedenis bewaren/tonen</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="81"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Let op&lt;/b&gt;: de grootte van widgets op het bovenste niveau is beperkt tot 2/3 van de hoogte en breedte van het bureaublad.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source>Show list with:</source>
        <translation>Lijst tonen met:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="91"/>
        <source> item(s)</source>
        <translation> item(s)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="115"/>
        <source>Clear input on launching</source>
        <translation>Invoer wissen na opstarten</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="132"/>
        <source>Shortcut:</source>
        <translation>Sneltoets:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Bovenste rand van beeldscherm</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Midden van beeldscherm</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>On Wayland, the shortcut has to be added
in the compositor settings for &apos;lxqt-runner&apos;.</source>
        <translation>Op Wayland dient de sneltoets voor ‘lxqt-runner’ te worden
toegevoegd in de vensterbeheerderinstellingen.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="83"/>
        <source>Focused screen</source>
        <translation>Actief scherm</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="87"/>
        <source>Always on screen %1</source>
        <translation>Altijd op scherm %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="96"/>
        <source>Reset</source>
        <translation>Standaardwaarden</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Programmastarter </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Configure</source>
        <translation>Instellen</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="113"/>
        <source>Clear History</source>
        <translation>Geschiedenis wissen</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="523"/>
        <source>Show/hide runner dialog</source>
        <translation>Uitvoerdervenster tonen/verbergen</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Berekening kopiëren naar klembord</translation>
    </message>
</context>
</TS>
